@@ -10,10 +10,11 @@ class ProductionRule:
     action = None
     ''' When specified the action is a function that takes am ExecutionContext as parameter'''
 
-    def __init__(self, source: NonTerminalToken, produced: List, action=None):
+    def __init__(self, source: NonTerminalToken, produced: List, action=None, data={}):
         self.source = source
         self.produced = produced
         self.action = action
+        self.data = data
 
     def __str__(self):
         produced = " ".join([p.__str__() for p in self.produced])
